@@ -35,7 +35,7 @@ end
     WGET::PARAM['wget'] = p
     case p
     when /wget$/
-      WGET::PARAM['opts'] = '-O -'
+      WGET::PARAM['opts'] = '-q -O -'
     when /lynx$/
       WGET::PARAM['opts'] = '-source'
     when /lwp-request$/
